@@ -25,13 +25,15 @@
 namespace auth;
 
 use conf\conf;
-use web\session;
+use upgrade\migrations;
 use web\request;
-use settings;
+use web\session;
+
 use anonymousUser;
-use user;
 use language;
 use log;
+use settings;
+use user;
 use userNotFoundException;
 
 /**
@@ -58,14 +60,10 @@ class web implements auth {
     public function __construct(session $session, request $request) {
         $this->session=$session;
         $this->request=$request;
+        $migrations=false;
         $this->redirect="logon.php";
         $this->lang = new language(conf::get("interface.language"));
 
-        if (conf::get("interface.user.remote") && $request->getServerVar("REMOTE_USER")) {
-            $remote_user = $request->getServerVar("REMOTE_USER");
-        } else {
-            $remote_user = false;
-        }
         if (isset($this->session['user'])) {
             $this->user = $this->session['user'];
         }
@@ -78,10 +76,17 @@ class web implements auth {
                     $this->user = $user;
                 } catch (userNotFoundException $e) {
                     $this->loginUser();
-                } 
+                }
             } else {
                 $this->loginUser();
             }
+            if ((!$this->user instanceof anonymousUser) && $this->user instanceof user && $this->checkMigrations()) {
+                $migrations = true;
+                if (!$this->user->isAdmin()) {
+                    $this->user=null;
+                    unset($this->session["user"]);
+                }
+            }
         }
 
         if ($this->user instanceof anonymousUser) {
@@ -97,9 +102,13 @@ class web implements auth {
         }
 
         if (!empty($this->user)) {
-            if (!empty($this->request["redirect"])) {
+            if ($migrations) {
+                $this->redirect="upgrade.php";
+            } else if (!empty($this->request["redirect"])) {
                 $this->setRedirect();
             }
+        } else if ($migrations) {
+            $this->setRedirectLogon("error=ADMINONLY&");
         } else if (!empty($this->request["uname"])) {
             /*  A username was given, but by now, no succesful logon has
                 happened so, we'll redirect, with error set to PWDFAIL.
@@ -220,5 +229,13 @@ class web implements auth {
         $this->redirect=preg_replace("/action=(?!search).[^&]+/", "action=display", $redirect);
     }
 
+    /**
+     * Check if there are any migrations to do
+     * if this is the case, only admin users can log on
+     * @return bool are there any migrations?
+     */
+    private function checkMigrations() {
+        return (new migrations())->check(conf::get("zoph.version"));
+    }
 }
 ?>
