@@ -201,13 +201,17 @@ class conf {
      * @param string label
      * @param string description
      */
-    public static function addGroup(collection $collection, $name, $label, $desc = "") {
+    public static function addGroup(collection $collection, $name, $label, $desc = "", $hidden = false) {
         $group = new group($collection);
 
         $group->setName($name);
         $group->setLabel($label);
         $group->setDesc($desc);
 
+        if($hidden) {
+            $group->setHidden();
+        }
+
 
         static::$groups[$name]=$group;
         return $group;
