@@ -51,6 +51,7 @@ class confDefault extends conf {
      * @todo naming is wrong, because config is not being 'get', it's stored in the object
      */
     protected static function getConfig() {
+        static::getConfigZoph();
         static::getConfigInterface();
         static::getConfigPath();
         static::getConfigMaps();
@@ -62,6 +63,25 @@ class confDefault extends conf {
         static::getConfigDate();
     }
 
+    /**
+     * Get config collection for Zoph
+     */
+    private static function getConfigZoph() {
+        $zoph = new collection();
+
+        $zophVersion = new text();
+        $zophVersion->setName("zoph.version");
+        $zophVersion->setLabel("Zoph Version");
+        $zophVersion->setDesc("The current version of Zoph. You should not need to change this. " .
+            "Changing this may lead to unexpected behaviour.");
+        $zophVersion->setDefault("v00.09.17.000");
+        $zophVersion->setRegex("^v([[0-9]{2}\.){3}[0-9]{3}");
+        $zophVersion->setInternal();
+        $zoph[]=$zophVersion;
+        conf::addGroup($zoph, "zoph", "Zoph general settings",
+            "Settings that define the inner workings of Zoph", true);
+
+    }
     /**
      * Get config collection for interface settings
      */
@@ -233,7 +253,7 @@ class confDefault extends conf {
         $pathImages->setName("path.images");
         $pathImages->setLabel("Images directory");
         $pathImages->setDesc("Location of the images on the filesystem. Absolute path, " .
-            " thus starting with a /");
+            "thus starting with a /");
         $pathImages->setDefault("/data/images");
         $pathImages->setRegex("^\/[A-Za-z0-9_.\/\-]+$");
         $pathImages->setHint("Alphanumeric characters (A-Z, a-z and 0-9), forward " .
@@ -288,8 +308,8 @@ class confDefault extends conf {
         $pathUnzip = new text();
         $pathUnzip->setName("path.unzip");
         $pathUnzip->setLabel("Unzip command");
-        $pathUnzip->setDesc("The command to use to unzip gzip files. Leave empty to " .
-            "disable uploading .gz files. On most systems \"unzip\" will work.");
+        $pathUnzip->setDesc("The command to use to unzip zip files. Leave empty to " .
+            "disable uploading .zip files. On most systems \"unzip\" will work.");
         $pathUnzip->setDefault("");
         $pathUnzip->setRegex("^([A-Za-z0-9_.\/ -]+|)$");
         $pathUnzip->setHint("Alphanumeric characters (A-Z, a-z and 0-9), forward " .
@@ -351,6 +371,7 @@ class confDefault extends conf {
 
         $mapsMapBoxAPIKey = new text();
         $mapsMapBoxAPIKey->setName("maps.mapbox.apikey");
+        $mapsMapBoxAPIKey->setLabel("Mapbox API key");
         $mapsMapBoxAPIKey->setDesc("API key to use to access MapBox. The default is Zoph's API key, please do not use it in other projects. If you are setting up a high-volume site, please consider requesting your own key");
         $mapsMapBoxAPIKey->setDefault("pk.eyJ1IjoiamVyb2Vucm5sIiwiYSI6ImNpdmh6dnlsazAwYWUydXBrbG50cHhlbmMifQ.0pSkJxO6ycD2Wg5GL4yYyw");
         $mapsMapBoxAPIKey->setRegex("^[0-9a-zA-Z\.]+$");
@@ -820,16 +841,6 @@ class confDefault extends conf {
         $featureMailBcc->setRegex("^([0-9a-zA-Z_\-%\.]+@([0-9a-zA-Z\-]+\.)+[a-zA-Z]{2,10})?$");
         $feature[]=$featureMailBcc;
 
-        $featureAnnotate = new checkbox();
-        $featureAnnotate->setName("feature.annotate");
-        $featureAnnotate->setLabel("Annotate photos");
-        $featureAnnotate->setDesc("A user can use the annotate photo function to e-mail a " .
-            "photo with a textual annotation. Can only be used in combination with the " .
-            "\"Mail photos\" feature above.");
-        $featureAnnotate->setDefault(false);
-        $featureAnnotate->setDeprecated();
-        $feature[]=$featureAnnotate;
-
         $featureRating = new checkbox();
         $featureRating->setName("feature.rating");
         $featureRating->setLabel("Photo rating");
