@@ -238,7 +238,6 @@ class web extends base {
      * use processFile() as a wrapper for this function
      * @see processFile
      * @param string full path to file
-     * @todo unpack_dir should be removed when done
      */
     private static function unpackArchive(file $file) {
         $dir = conf::get("path.images") . "/" . conf::get("path.upload");
@@ -286,7 +285,7 @@ class web extends base {
         $files=file::getFromDir($unpack_dir, true);
         foreach ($files as $import_file) {
             $type=$import_file->type;
-            if ($type == "image" || $type == "archive" || $type || "xml") {
+            if ($type == "image" || $type == "archive" || $type == "xml") {
                 $import_file->setDestination($dir);
                 try {
                     $import_file->move();
@@ -295,6 +294,22 @@ class web extends base {
                 }
             }
         }
+        static::removeDir($unpack_dir);
+    }
+
+    /**
+     * Remove dirs
+     * Remove temporary directories that were created when unpacking an archive
+     * Only removes emptry directories, a warning will be displayed when there are still files
+     * left in the directory. This could happen when something went wrong during import or
+     * non-image files were present in the archive.
+     * @param string directory to traverse.
+     */
+    private static function removeDir(string $dir) {
+        foreach (glob($dir . "/*" ,  GLOB_ONLYDIR) as $subdir) {
+            static::removeDir($subdir);
+        }
+        rmdir($dir);
     }
 
     /**
@@ -463,9 +478,9 @@ class web extends base {
                 $xmlfile->appendChild($xmlstatus);
             }
 
-            if (isset($subjects) && is_array($subjects) && sizeof($subjects) > 0) {
+            if (isset($subjects) && !empty($subjects)) {
                 $xmlsubjects=$xml->createElement("subjects");
-                foreach($subjects as $subject) {
+                foreach ($subjects as $subject) {
                     $xmlsubjects->appendChild($xml->createElement("subject", $subject));
                 }
                 $xmlfile->appendChild($xmlsubjects);
