@@ -31,9 +31,13 @@ use log;
  */
 class reader  {
 
-    /** @param array names of XMP/rdf containers */
+    /** @var array names of XMP/rdf containers */
     private static $containers = array("rdf:Seq", "rdf:Bag", "rdf:Alt");
+    /** @var array names of XMP/rdf container elements */
+    private static $containerElements = array("rdf:li");
+    /** @var array xmp data */
     private $xmpdata = array();
+    /** @var array file data - file contents */
     private $XMPs = array();
 
     /** @param array Extensions to try for XMP Sidecar files */
@@ -42,17 +46,19 @@ class reader  {
 
     /**
      * Create new xmp/reader object
-     * @param string file to read
+     * @param file file to read
      */
     public function __construct(file $file) {
         $this->file = $file;
     }
 
+    /**
+     * Read XMP from sidecar files
+     */
     public function getXMPfromSidecar() {
         log::msg("Loading XMP from sidecar files", log::NOTIFY, log::IMPORT);
-        $fnNoExt = $this->file->getNameNoExt();
         foreach ($this->XMPext as $ext) {
-            foreach(array($this->file->getName(), $this->file->getNameNoExt()) as $name) {
+            foreach (array($this->file->getName(), $this->file->getNameNoExt()) as $name) {
                 $filename = $this->file->getPath() . "/" . $name . "." . $ext;
                 log::msg("Trying " . $filename, log::DEBUG, log::IMPORT);
                 if (file_exists($filename)) {
@@ -65,9 +71,12 @@ class reader  {
         }
         log::msg("No sidecar file found", log::NOTIFY, log::IMPORT);
         return array();
-        
+
     }
 
+    /**
+     * Read XMP from file
+     */
     public function getXMP() {
         $this->file->getMime();
         switch ($this->file->type) {
@@ -86,7 +95,6 @@ class reader  {
         foreach ($this->xmpdata as $xmp) {
             $return[] = new data($xmp);
         }
-
         return $return;
     }
 
@@ -124,13 +132,13 @@ class reader  {
         $open = false;
 
         while (($data = fread($fp, 1024)) !== false) {
-            if($data === "") {
+            if ($data === "") {
                 break;
             }
             $buffer .= $data;
-            if(!$open) {
+            if (!$open) {
                 $openpos =strpos($buffer, "<x:xmpmeta");
-                if($openpos !== false) {
+                if ($openpos !== false) {
                     $open = true;
                 } else {
                     // keep 12 bytes of buffer, in case the XMP is right on the edge
@@ -138,7 +146,7 @@ class reader  {
                 }
             } else {
                 $closepos =strpos($buffer, "</x:xmpmeta>");
-                if($closepos !== false) {
+                if ($closepos !== false) {
                     $this->XMPs[] = substr($buffer, $openpos, ($closepos - $openpos) + 12);
                     $open = false;
                     $buffer = substr($buffer, $closepos + 11);
@@ -147,35 +155,24 @@ class reader  {
         }
     }
 
-    private function decodeXMLcontainer(XMLReader $xml) {
-        $node=array();
-        if(in_array($xml->name, self::$containers)) {
-            $container = $xml->name;
-        }
-        while(!($xml->nodeType==XMLReader::END_ELEMENT && $xml->name==$container)) {
-            $xml->read();
-            if ($xml->nodeType==XMLReader::ELEMENT && ($xml->name=="rdf:li" || in_array($xml->name, self::$containers))) {
-                $node[]=$this->decodeXMLcontainer($xml);
-            } else if ($xml->nodeType==XMLReader::TEXT) {
-                return $xml->value;
-            } else if ($xml->nodeType==XMLReader::END_ELEMENT) {
-            } else if ($xml->nodeType==XMLReader::SIGNIFICANT_WHITESPACE) {
-            } else {
-                /** @todo define exception and provide proper error */
-                throw new \Exception("Failed");
-            }
-        }
-        return $node;
-    }
-
     private function decodeXML(XMLReader $xml) {
         $node=array();
-        while($xml->read()) {
+        while ($xml->read()) {
             if ($xml->nodeType==XMLReader::ELEMENT) {
                 $nodename = $xml->name;
 
-                $empty=$xml->isEmptyElement;
+                if (in_array($nodename, self::$containers)) {
+                    $container = $nodename;
+                    $containerElement = false;
+                } else if (in_array($nodename, self::$containerElements)) {
+                    $container = false;
+                    $containerElement = true;
+                } else {
+                    $container = false;
+                    $containerElement = false;
+                }
 
+                $empty=$xml->isEmptyElement;
                 if ($xml->hasAttributes) {
                     $attr=array();
                     $xml->moveToFirstAttribute();
@@ -183,28 +180,35 @@ class reader  {
                     do {
                         $attr[$xml->name] = $xml->value;
                     } while ($xml->moveToNextAttribute());
+
                     if (!$empty) {
-                        $node[$nodename]=array_merge($attr, $this->decodeXML($xml));
+                        $data=array_merge($attr, (array) $this->decodeXML($xml));
                     } else {
-                        $node[$nodename]=$attr;
+                        $data=$attr;
                     }
                 } else if ($xml->hasValue) {
-                    $node[] = $xml->value;
+                    $data = $xml->value;
                 } else {
-                    if (in_array($nodename, self::$containers)) {
-                        $node[$nodename]=$this->decodeXMLcontainer($xml);
-                    } else {
-                        $node[$nodename]=$this->decodeXML($xml);
+                    $data=$this->decodeXML($xml);
+                }
+                if($container) {
+                    $node = $data;
+                } else if ($containerElement) {
+                    $node[] =$data;
+                } else {
+                    if(!is_array($node)) {
+                        $node = array($node);
                     }
+                    $node[$nodename] = $data;
                 }
 
             } else if ($xml->nodeType==XMLReader::TEXT) {
-                $node[]=$xml->value;
+                $node = $xml->value;
             } else if ($xml->nodeType==XMLReader::END_ELEMENT) {
-                return $node;
-            } else if ($xml->nodeType==XMLReader::WHITESPACE) {
-            } else if ($xml->nodeType==XMLReader::SIGNIFICANT_WHITESPACE) {
-            } else {
+                break;
+            } else if (($xml->nodeType != XMLReader::WHITESPACE) &&
+                       ($xml->nodeType != XMLReader::SIGNIFICANT_WHITESPACE) &&
+                       ($xml->nodeType != XMLReader::PI)) {
                 $node[] = $xml->value;
             }
         }
