@@ -28,7 +28,6 @@ require_once "autoload.inc.php";
 require_once "settings.inc.php";
 require_once "variables.inc.php";
 $hash = getvar("hash");
-$annotated = getvar('annotated');
 $type = getvar("type");
 if ($type == "background") {
     define("IMAGE_BG", 1);
@@ -77,13 +76,6 @@ if (($type=="import_thumb" || $type=="import_mid") &&
             exit;
         }
     }
-} else if (conf::get("feature.annotate") && $annotated) {
-    $photo = new annotatedPhoto($photo_id);
-    $found = $photo->lookup();
-    $photo->setVars($request_vars);
-    if (getvar("_size")=="mid") {
-        $type=MID_PREFIX;
-    }
 } else if ($type==MID_PREFIX || $type==THUMB_PREFIX || empty($type)) {
     $photo = new photo($photo_id);
     $found = $photo->lookup();
