@@ -231,7 +231,7 @@ var zImport=function() {
                             img=document.createElement("img");
                             switch(status) {
                             case "done":
-                                if(type=="xml") {
+                                if(type=="gpx") {
                                     imgsrc=icon;
                                     importli=document.createElement("li");
                                     xmlimport=createNode("a", translate['import']);
