@@ -20,22 +20,6 @@ var zMaps=function() {
         var map = L.map('map').setView([0,0],1);
 
         switch(provider) {
-        case "googlev3":
-            var street = L.gridLayer.googleMutant( {
-                type: 'roadmap'
-            }).addTo(map);
-            var sat = L.gridLayer.googleMutant( {
-                type: 'satellite'
-            }).addTo(map);
-            // Hybrid mode is not working correctly yet
-            //var hybrid = L.gridLayer.googleMutant( {
-            //    type: 'hybrid'
-            //}).addTo(map);
-            layers = { 
-                "Satellite": sat,
-                "Streetmap": street
-            };
-            break;
         case "mapbox":
             var url="https://api.mapbox.com/styles/v1/{id}/tiles/{z}/{x}/{y}?access_token={accessToken}";
             var maxZoom=18;
@@ -50,24 +34,15 @@ var zMaps=function() {
                 accessToken: mapbox_api_key
             }).addTo(map);
 
-            var sat=L.tileLayer(url, {
+            var sat=L.tileLayer("https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token={accessToken}", {
                 attribution: attr,
-                maxZoom: maxZoom,
+                maxZoom: 17,
                 id: 'mapbox.satellite',
                 detectRetina: true,
                 accessToken: mapbox_api_key
             }).addTo(map);
 
-            var strsat=L.tileLayer(url, {
-                attribution: attr,
-                maxZoom: maxZoom,
-                id: 'mapbox.streets-satellite',
-                detectRetina: true,
-                accessToken: mapbox_api_key
-            }).addTo(map);
-
             layers = { 
-                "Streetmap + Satellite": strsat,
                 "Satellite": sat,
                 "Streetmap": street
             };
