@@ -28,7 +28,15 @@ var zRating=function() {
         return(div);
     }
 
+    function ratingButton(inputId, dropdownId) {
+        input = document.getElementById(inputId);
+        dropdown = document.getElementById(dropdownId);
+        
+        input.disabled = (dropdown.value == "0");
+    }
+
     return {
-        rating:rating
+        rating:rating,
+        ratingButton:ratingButton
     };
 }();
