@@ -23,6 +23,7 @@
  */
 use conf\conf;
 use template\template;
+use upgrade\migrations;
 
 define("LOGON", true);
 
@@ -37,19 +38,29 @@ if (isset($_GET["redirect"])) {
 $user = new user();
 $lang=$user->loadLanguage();
 
+$warning = "";
+$migrations = new migrations();
+if ($migrations->check(conf::get("zoph.version"))) {
+    $warning = translate("The upgrade of Zoph has not been completed, only admin user can logon");
+}
+
 $error="";
 if (!is_null(getvar("error"))) {
     switch (getvar("error")) {
     case "PWDFAIL":
         $error=translate("You have entered an incorrect username/password combination");
         break;
+    case "ADMINONLY":
+        $error=translate("Only admin users can logon now");
+        break;
     }
 }
 
 $tpl=new template("logon", array(
     "title"     =>  conf::get("interface.title"),
     "redirect"  =>  $redirect,
-    "error"     =>  $error
+    "error"     =>  $error,
+    "warning"   =>  $warning
 ));
 
 echo $tpl;
