@@ -28,8 +28,12 @@ if (!ZOPH) {
 
 <div class="message <?= $tpl_class ?>">
     <img class='icon' src='<?php echo template::getImage("icons/" . $tpl_class . ".png") ?>'>
+    <?php if (isset($tpl_title)): ?>
+        <h1><?= $tpl_title ?></h1>
+    <?php endif ?>
     <div class="messageText"><?= $tpl_text ?></div>
     <br>
+    <?= $this->getActionlinks() ?>
 </div>
 
 
