@@ -1750,12 +1750,6 @@ div.formtext {
     padding: 15px;
 }
 
-/* Checkbox on the annotate photo page */
-
-.checkbox   {
-    text-align: right;
-}
-
 div.editchoice  {
     position: relative;
     z-index: 5;
@@ -2570,12 +2564,14 @@ ul.calendar li.photos:hover {
 
 /* message */
 .message  {
+    width: 80%;
     text-align: center;
-    margin: 10px 0px;
+    margin: 10px auto;
     padding:12px;
     clear: both;
     border-radius: 10px;
     box-shadow: 5px 5px 5px rgba(0,0,0,0.4);
+    overflow: hidden;
 }
 
 div.message img.icon {
@@ -2587,7 +2583,10 @@ div.message div.messageText {
     float: left;
     width: 80%;
 }
+
+div.message h1,
 div.message div.messageText h1 {
+    clear: none;
     border: none;
     background: transparent;
     text-align: center;
@@ -2599,6 +2598,22 @@ div.message div.messageText h1 {
 
 }
 
+div.message ul.actionlink {
+    clear: both;
+    font-weight: bold;
+    font-size: large;
+}
+
+div.message ul.actionlink a {
+    color: inherit;
+}
+
+div.message ul.actionlink li::after,
+div.message ul.actionlink li::before {
+    opacity: 50%;
+    color: inherit;
+}
+
 .info {
     color: #00529B;
     background-color: #BDE5F8;
@@ -2702,6 +2717,72 @@ ul#errors li.deleted {
     animation: delete 2s forwards;
 }
 
+div.result {
+    line-height: 2em;
+}
+
+div.results {
+    width: 80%;
+    margin: 4em auto;
+}
+div.results h3 {
+    font-size: x-large;
+    margin: 1em;
+}
+
+div.result img {
+    float: left;
+    width: 24px;
+    height: 24px;
+    margin: 0 1em 0 0;
+}
+
+div.result div.error {
+    margin: 6px;
+    padding: 2px;
+}
+
+div.result div.error:empty {
+    display: none;
+}
+
+a.button {
+    font-size: x-large;
+    font-weight: bold;
+    display: block;
+    margin: 4em;
+    padding: 1em;
+    border-radius: 10px;
+    box-shadow: 10px 10px 10px rgba(0,0,0,0.5);
+    text-align: center;
+    text-decoration: none;
+   vertical-align: middle;
+}
+
+a.button:hover {
+    position: relative;
+    left: 5px;
+    top: 5px;
+    box-shadow: 5px 5px 5px rgba(0,0,0,0.8);
+}
+
+.green {
+   border-top: 1px solid #97f7a4;
+   background-image: linear-gradient(rgba(62,156,74,90%), rgba(101,212,115,70%));
+   text-shadow: rgba(0,0,0,.4) 0 1px 0;
+   color: white;
+}
+
+.green:hover {
+   border-top-color: #287832;
+   background: #287832;
+}
+
+.green:active {
+   border-top-color: #1b5c23;
+   background: #1b5c23;
+}
+
 @keyframes delete {
     0% {
         opacity: 1;
