@@ -27,7 +27,7 @@ if (!ZOPH) {
     <?= $tpl_title ?>
 </h1>
 <div class="main">
-    <h2><?= translate("Group") ?></h2>
+    <h2><?= translate("group") ?></h2>
     <dl class="group">
         <?php foreach ($tpl_fields as $title => $value): ?>
             <dt><?= $title ?></dt>
